@@ -11,54 +11,12 @@
 #' @param fun is the objective function. It should receive a matrix x and return a matrix y. In case the function uses external code and is noisy, an additional seed parameter may be used, see the \code{control$seedFun} argument below for details.
 #' @param lower is a vector that defines the lower boundary of search space. This determines also the dimensionality of the problem.
 #' @param upper is a vector that defines the upper boundary of search space.
-#' @param control is a list of additional settings: 
-#' \describe{
-#'   \item{\code{funEvals}}{ This is the budget of function evaluations (spot uses no more than funEvals evaluations of fun), defaults to 20.}
-#'   \item{\code{types}}{ Vector of data type of each variable as a string, defaults \code{"numeric"} for all variables.}
-#'   \item{\code{design}}{A function that creates an initial design of experiment. Functions that accept the same parameters, 
-#'				and return a matrix like \code{\link{designLHD}} or \code{\link{designUniformRandom}} can be used. Default is \code{\link{designLHD}}.}
-#'   \item{\code{designControl}}{A list of controls based to the \code{control} list of the \code{design} function. See help 
-#'				of the respective function for details. Default is an empty \code{list}.}
-#'   \item{\code{model}}{A function that builds a statistical model of the observed data. Functions that accept the same 
-#'				parameters, and return a matrix like \code{\link{buildKriging}} or \code{\link{buildRandomForest}} 
-#'				can be used. Default is \code{\link{buildKriging}}.}
-#'   \item{\code{modelControl}}{A list of controls based to the \code{control} list of the \code{model} function. 
-#'				See help of the respective function for details.Default is an empty \code{list}.}
-#'   \item{\code{optimizer}}{A function that is used to optimize based on \code{model}, finding the most promising 
-#'				candidate solutions. Functions that accept the same parameters, and return a matrix like \code{\link{optimLHD}} 
-#'				or \code{\link{optimLBFGSB}} can be used. Default is \code{\link{optimLHD}}.}
-#'   \item{\code{optimizerControl}}{A list of controls based to the \code{control} list of the \code{optimizer} function. 
-#'				See help of the respective function for details. Default is an empty \code{list}.}
-#'   \item{\code{noise}}{Boolean, whether the objective function has noise or not. Default is non-noisy, that is, \code{FALSE}.}
-#'   \item{\code{OCBA}}{Boolean, indicating whether Optimal Computing Budget Allocation (OCBA) should be used in case of a noisy 
-#'				objective function or not. OCBA controls the number of replications for each candidate solution. 
-#' 				Note, that \code{replicates} should be larger than one in that case, and that the initial experimental design 
-#'				(see \code{design}) should also have replicates larger one. Default is \code{FALSE}.}
-#'   \item{\code{OCBAbudget}}{The number of objective function evaluations that OCBA can distribute in each iteration. Default is 3.}
-#'   \item{\code{replicates}}{The number of times a candidate solution is initially evaluated, that is, in the initial design, 
-#'				or when created by the optimizer. Default is \code{1}.}
-#'   \item{\code{seedFun}}{An initial seed for the objective function in case of noise, by default \code{NA}. The default means that no seed is set.
-#'				The user should be very careful with this setting. It is intended to generate reproducible experiments for each objective
-#'				function evaluation, e.g., when tuning non-deterministic algorithms. If the objective function uses a constant number
-#'				of random number generations, this may be undesirable. Note, that this seed is by default set prior to each evaluation. A replicated
-#'				evaluation will receive an incremented value of the seed.
-#'				Sometimes, the user may want to call external code using random numbers. To allow for that case, the user can specify an objective function (\code{fun}),
-#' 				which has a second parameter \code{seed}, in addition to first parameter (matrix \code{x}). This seed can then be passed
-#'				to the external code, for random number generator initialization. See end of examples section for a demonstration.}
-#'   \item{\code{seedSPOT}}{This value is used to initialize the random number generator. It ensures that experiments are reproducible. Default is \code{1}.}
-#'   \item{\code{duplicate}}{In case of a deterministic (non-noisy) objective function, this handles duplicated candidate solutions.
-#'				By default (\code{duplicate = "EXPLORE"}), duplicates are replaced by new candidate solutions, generated by random 
-#'				sampling with uniform distribution. If desired, the user can set this to "STOP", which means that the optimization
-#'				stops and results are returned to the user (with a warning). This may be desirable, as duplicates can be a indicator
-#'				for convergence, or for a problem with the configuration.
-#'				In case of noise, duplicates are allowed.}
-#'   \item{\code{plots}}{Whether progress should be tracked by a line plot, default is false}
-#' }
+#' @param control is a list with control settings for spot. See \code{\link{spotControl}}.
 #' @param ... additional parameters passed to \code{fun}.
 #'
 #' @return This function returns a list with:
 #' \describe{
-#'		\item{{xbest}}{Parameters of the best found solution (matrix).}
+#'		\item{\code{xbest}}{Parameters of the best found solution (matrix).}
 #'		\item{\code{ybest}}{Objective function value of the best found solution (matrix).}
 #'		\item{\code{x}}{Archive of all evaluation parameters (matrix).}
 #'		\item{\code{y}}{Archive of the respective objective function values (matrix).}
@@ -150,9 +108,85 @@ spot <- function(x=NULL,fun, #mostly, fun must have format y=f(x,...).
 		## be fun(x,seed,...)
 		lower,upper,control=list(),...){
 	## default settings
-	con <- list(
+	dimension <- length(lower)
+	con <- spotControl(dimension)
+	con[names(control)] <- control
+	control <- con
+	rm(con)
+
+	## All functions should deal with the same data types 
+	control$designControl$types <- control$types
+	control$modelControl$types <- control$types
+	control$optimizerControl$types <- control$types
+	
+	## Initial design generation
+	set.seed(control$seedSPOT)
+  x <- control$design(x,lower,upper,control$designControl)
+  
+	## Evaluate initial design with objective function
+  y <- objectiveFunctionEvaluation(NULL,x,fun,control$seedFun,control$noise,...)
+	
+	result <- spotLoop(x,y,fun,lower,upper,control, ...)
+	result
+} 
+
+###################################################################################################
+#' Default Control list for spot 
+#'
+#' This function returns the default controls for the functions \code{\link{spot}} and \code{\link{spotLoop}}.
+#' Control is a list of the settings: 
+#' \describe{
+#'   \item{\code{funEvals}}{ This is the budget of function evaluations (spot uses no more than funEvals evaluations of fun), defaults to 20.}
+#'   \item{\code{types}}{ Vector of data type of each variable as a string, defaults \code{"numeric"} for all variables.}
+#'   \item{\code{design}}{A function that creates an initial design of experiment. Functions that accept the same parameters, 
+#'				and return a matrix like \code{\link{designLHD}} or \code{\link{designUniformRandom}} can be used. Default is \code{\link{designLHD}}.}
+#'   \item{\code{designControl}}{A list of controls based to the \code{control} list of the \code{design} function. See help 
+#'				of the respective function for details. Default is an empty \code{list}.}
+#'   \item{\code{model}}{A function that builds a statistical model of the observed data. Functions that accept the same 
+#'				parameters, and return a matrix like \code{\link{buildKriging}} or \code{\link{buildRandomForest}} 
+#'				can be used. Default is \code{\link{buildKriging}}.}
+#'   \item{\code{modelControl}}{A list of controls based to the \code{control} list of the \code{model} function. 
+#'				See help of the respective function for details.Default is an empty \code{list}.}
+#'   \item{\code{optimizer}}{A function that is used to optimize based on \code{model}, finding the most promising 
+#'				candidate solutions. Functions that accept the same parameters, and return a matrix like \code{\link{optimLHD}} 
+#'				or \code{\link{optimLBFGSB}} can be used. Default is \code{\link{optimLHD}}.}
+#'   \item{\code{optimizerControl}}{A list of controls based to the \code{control} list of the \code{optimizer} function. 
+#'				See help of the respective function for details. Default is an empty \code{list}.}
+#'   \item{\code{noise}}{Boolean, whether the objective function has noise or not. Default is non-noisy, that is, \code{FALSE}.}
+#'   \item{\code{OCBA}}{Boolean, indicating whether Optimal Computing Budget Allocation (OCBA) should be used in case of a noisy 
+#'				objective function or not. OCBA controls the number of replications for each candidate solution. 
+#' 				Note, that \code{replicates} should be larger than one in that case, and that the initial experimental design 
+#'				(see \code{design}) should also have replicates larger one. Default is \code{FALSE}.}
+#'   \item{\code{OCBAbudget}}{The number of objective function evaluations that OCBA can distribute in each iteration. Default is 3.}
+#'   \item{\code{replicates}}{The number of times a candidate solution is initially evaluated, that is, in the initial design, 
+#'				or when created by the optimizer. Default is \code{1}.}
+#'   \item{\code{seedFun}}{An initial seed for the objective function in case of noise, by default \code{NA}. The default means that no seed is set.
+#'				The user should be very careful with this setting. It is intended to generate reproducible experiments for each objective
+#'				function evaluation, e.g., when tuning non-deterministic algorithms. If the objective function uses a constant number
+#'				of random number generations, this may be undesirable. Note, that this seed is by default set prior to each evaluation. A replicated
+#'				evaluation will receive an incremented value of the seed.
+#'				Sometimes, the user may want to call external code using random numbers. To allow for that case, the user can specify an objective function (\code{fun}),
+#' 				which has a second parameter \code{seed}, in addition to first parameter (matrix \code{x}). This seed can then be passed
+#'				to the external code, for random number generator initialization. See end of examples section for a demonstration.}
+#'   \item{\code{seedSPOT}}{This value is used to initialize the random number generator. It ensures that experiments are reproducible. Default is \code{1}.}
+#'   \item{\code{duplicate}}{In case of a deterministic (non-noisy) objective function, this handles duplicated candidate solutions.
+#'				By default (\code{duplicate = "EXPLORE"}), duplicates are replaced by new candidate solutions, generated by random 
+#'				sampling with uniform distribution. If desired, the user can set this to "STOP", which means that the optimization
+#'				stops and results are returned to the user (with a warning). This may be desirable, as duplicates can be a indicator
+#'				for convergence, or for a problem with the configuration.
+#'				In case of noise, duplicates are allowed.}
+#'   \item{\code{plots}}{Whether progress should be tracked by a line plot, default is false}
+#' }
+#' @param dimension dimensionality of the problem, that is, the number of optimzed parameters.
+#' @return a list
+#' @export
+#' @keywords internal
+#' spotDefaultControls()
+###################################################################################################
+spotControl <- function(dimension){
+list(
     funEvals=20,
-		types= rep("numeric",length(lower)),
+		types= rep("numeric",dimension),
     design = designLHD,
     designControl = list(),
     model = buildKriging,
@@ -177,26 +211,60 @@ spot <- function(x=NULL,fun, #mostly, fun must have format y=f(x,...).
     ## The exception from this rule should be if noise==FALSE, in that case, duplicates are removed.
 		## (?) TODO -> what if only one duplicate suggested -> will be suggested again in next iteration?
   )
+}
+
+###################################################################################################
+#' Sequential Parameter Optimization Main Loop
+#'
+#' SPOT is usually started via the function \code{\link{spot}}. However, SPOT runs can be continued
+#' (i.e., with a larger budget specified in \code{control$funEvals}) by using \code{spotLoop}.
+#' This is the main loop of SPOT iterations. It requires the user to give the same inputs as
+#' specified for \code{\link{spot}}.
+#' 
+#' @param x are the known candidate solutions that the SPOT loop is started with, specified as a matrix. One row for each point, and one column for each optimized parameter.
+#' @param y are the corresponding observations for each solution in \code{x}, specified as a matrix. One row for each point.
+#' @param fun is the objective function. It should receive a matrix x and return a matrix y. In case the function uses external code and is noisy, an additional seed parameter may be used, see the \code{control$seedFun} argument below for details.
+#' @param lower is a vector that defines the lower boundary of search space. This determines also the dimensionality of the problem.
+#' @param upper is a vector that defines the upper boundary of search space.
+#' @param control is a list with control settings for spot. See \code{\link{spotControl}}.
+#' @param ... additional parameters passed to \code{fun}.
+#'
+#' @return This function returns a list with:
+#' \describe{
+#'		\item{{xbest}}{Parameters of the best found solution (matrix).}
+#'		\item{\code{ybest}}{Objective function value of the best found solution (matrix).}
+#'		\item{\code{x}}{Archive of all evaluation parameters (matrix).}
+#'		\item{\code{y}}{Archive of the respective objective function values (matrix).}
+#'		\item{\code{count}}{Number of performed objective function evaluations.}
+#'		\item{\code{msg}}{Message specifying the reason of termination.}
+#'		\item{\code{modelFit}}{The fit of the last build model, i.e., an object returned by the last call to the function specified by \code{control$model}.}
+#' }
+#'
+#' @examples
+#' ## Most simple example: Kriging + LHS + predicted 
+#' ## mean optimization (not expected improvement)
+#' control <- list(funEvals=20)
+#' res <- spot(,funSphere,c(-2,-3),c(1,2),control)
+#' ## now continue with larger budget
+#' control$funEvals <- 25
+#' res2 <- spotLoop(res$x,res$y,funSphere,c(-2,-3),c(1,2),control)
+#' res2$xbest
+#' res2$ybest
+#' @export
+###################################################################################################
+spotLoop <- function(x,y,fun,lower,upper,control,...){
+	## default settings
+	dimension <- length(lower)
+	con <- spotControl(dimension)
 	con[names(control)] <- control
 	control <- con
 	rm(con)
-
-	## All functions should deal with the same data types 
-	control$designControl$types <- control$types
-	control$modelControl$types <- control$types
-	control$optimizerControl$types <- control$types
-	
-	## Initial design generation
-	set.seed(control$seedSPOT)
-  x <- control$design(x,lower,upper,control$designControl)
-  
-	## Evaluate initial design with objective function
-  y <- objectiveFunctionEvaluation(NULL,x,fun,control$seedFun,control$noise,...)
 	
 	## Initialize evaluation counter
   count <- nrow(y)
   
 	## Main Loop
+	modelFit <- NA
 	while(count < control$funEvals){ 
 		## Model building 
     modelFit <- control$model(x,y,control$modelControl) #todo return modelControl to allow memory?
@@ -240,4 +308,4 @@ spot <- function(x=NULL,fun, #mostly, fun must have format y=f(x,...).
     
   indexBest <- which.min(y)
   list(xbest=x[indexBest,,drop=FALSE],ybest=y[indexBest,,drop=FALSE],x=x, y=y, count=count,msg="budget exhausted",modelFit=modelFit)
-} 
+}	
\ No newline at end of file
